@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::APIAccess;
-$Net::Kubernetes::Role::APIAccess::VERSION = '0.03';
+$Net::Kubernetes::Role::APIAccess::VERSION = '0.04';
 use Moose::Role;
 require LWP::UserAgent;
 require HTTP::Request;
@@ -13,7 +13,7 @@ Net::Kubernetes::Role::APIAccess
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =cut
 
@@ -69,8 +69,14 @@ around BUILDARGS => sub {
 	my $orig = shift;
 	my $class = shift;
 	my(%input) = @_;
-	if(ref($input{token}) && $input{token}->can('getlines')){
-		$input{token} = join('', $input{token}->getlines);
+	if(ref($input{token})){
+		if($input{token}->can('getlines')){
+			$input{token} = join('', $input{token}->getlines);
+		}
+		elsif (ref($input{token}) eq 'GLOB') {
+			my $fh = $input{token};
+			$input{token} = do{ local $/; <$fh>};
+		}
 	}elsif (exists $input{token} && -f $input{token}) {
 		open(my $fh, '<', $input{token});
 		$input{token} = do{ local $/; <$fh>};
