@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::ResourceCreator;
-$Net::Kubernetes::Role::ResourceCreator::VERSION = '0.03';
+$Net::Kubernetes::Role::ResourceCreator::VERSION = '0.04';
 use Moose::Role;
 use MooseX::Aliases;
 require YAML;
@@ -17,7 +17,7 @@ Net::Kubernetes::Role::ResoruceCreator
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =cut
 
@@ -39,7 +39,7 @@ sub create_from_file {
 		$object = YAML::LoadFile($file);
 	}
 	else{
-		$object = $self->json->decode(read_file($file));
+		$object = $self->json->decode(scalar(read_file($file)));
 	}
 	
 	return $self->create($object);
@@ -54,7 +54,6 @@ sub create {
 	}else{
 		Net::Kubernetes::Exception->throw(code=>$res->code, message=>"Error creating resource:\n".$res->message);
 	}
-	
 }
 
 
